@@ -12,6 +12,8 @@ from gerrit.utils.exceptions import UnsupportMethod
 
 class GerritChange(BaseModel):
     def __init__(self, **kwargs):
+        self.revisions = {}
+        self.current_revision_number = 0
         super(GerritChange, self).__init__(**kwargs)
 
     def create_merge_patch_set(self, input_):
@@ -69,6 +71,59 @@ class GerritChange(BaseModel):
         result = self.gerrit.decode_response(response)
         return result
 
+    def list_votes(self, account):
+        """
+        Lists the votes for a specific reviewer of the change.
+
+        :param account: account id or username
+        :return:
+        """
+        endpoint = "/changes/%s/reviewers/%s/votes" % (self.id, account)
+        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
+        result = self.gerrit.decode_response(response)
+        return result
+
+    def delete_vote(self, account, label, input_=None):
+        """
+        Deletes a single vote from a change. Note, that even when the last vote of a reviewer is removed the reviewer
+        itself is still listed on the change.
+        If another user removed a user’s vote, the user with the deleted vote will be added to the attention set.
+
+        .. code-block:: python
+
+            input_ = {
+                "notify": "NONE"
+            }
+
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change.delete_vote('John', 'Code-Review', input_)
+            # or
+            change.delete_vote('John', 'Code-Review')
+
+        :param account:
+        :param label:
+        :param input_: the DeleteVoteInput entity,
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#delete-vote-input
+        :return:
+        """
+        if input_ is None:
+            endpoint = "/changes/%s/reviewers/%s/votes/%s" % (
+                self.change,
+                account,
+                label,
+            )
+            self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        else:
+            endpoint = "/changes/%s/reviewers/%s/votes/%s/delete" % (
+                self.change,
+                account,
+                label,
+            )
+            base_url = self.gerrit.get_endpoint_url(endpoint)
+            self.gerrit.requester.post(
+                base_url, json=input_, headers=self.gerrit.default_headers
+            )
+
     def get_topic(self):
         """
         Retrieves the topic of a change.
@@ -680,18 +735,47 @@ class GerritChange(BaseModel):
     def reviewers(self):
         return GerritChangeReviewers(change=self.id, gerrit=self.gerrit)
 
-    def get_revision(self, revision_id):
-        """
-        get one revision by revision id
+    def __get_revisions(self):
+        endpoint = "/changes/?q=%s&o=ALL_REVISIONS" % self.number
+        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
+        [result] = self.gerrit.decode_response(response)
+        self.revisions = {}
+        for revision_sha, revision in result["revisions"].items():
+            if result["current_revision"] == revision_sha:
+                self.current_revision_number = revision["_number"]
+            self.revisions[revision["_number"]] = revision_sha
 
-        :param revision_id:
+    def __revision_number_to_sha(self, number):
+        if number in self.revisions:
+            return self.revisions[number]
+        return None
+
+    def get_revision(self, revision_id="current"):
+        """
+        Get one revision by revision SHA or integer number.
+
+        :param revision_id: Optional ID. If not specified, the current revision will be retrieved.
+                            It supports SHA IDs and integer numbers from -X to +X, where X is the
+                            current (latest) revision.
+                            Zero means current revision.
+                            -N means the current revision number X minus N, so if the current
+                            revision is 50, and -1 is given, the revision 49 will be retrieved.
         :return:
         """
+        if isinstance(revision_id, int):
+            if len(self.revisions) == 0:
+                self.__get_revisions()
+            if revision_id <= 0:
+                revision_id = self.current_revision_number + revision_id
+            revision_id = self.__revision_number_to_sha(revision_id)
+            if revision_id is None:
+                return None
+
         return GerritChangeRevision(
+            gerrit=self.gerrit,
             project=self.project,
             change=self.id,
-            revision=revision_id,
-            gerrit=self.gerrit,
+            revision=revision_id
         )
 
     def get_attention_set(self):
