@@ -21,6 +21,14 @@ class ServerError(GerritAPIException):
     pass
 
 
+class UnauthorizedError(GerritAPIException):
+    """
+    401 Unauthorized
+    """
+
+    pass
+
+
 class AuthError(ClientError):
     """
     403 Forbidden is returned if the operation is not allowed because the calling user does not have sufficient permissions.
@@ -91,4 +99,5 @@ class UnsupportMethod(Exception):
     """
     This Error will be raised when program calls methods or parameters that are currently unsupported
     """
+
     pass
